﻿using System.Collections.Generic;
using UnityEngine;

public class EnemySystem : MonoBehaviour
{
    [SerializeField] private float _baseSpawnEveryXSeconds = default;
    [SerializeField] private Transform _spawnPosition = default;
    [SerializeField] private Enemy _protoEnemy = default;
    [SerializeField] private EnemyType[] _types = default;
    [SerializeField] private Transform[] _bouncePoints = default;
    [SerializeField] private PlacementSystem _placeSys = default;
    [SerializeField] private PeopleSystem _peopleSys = default;

    public IEnumerable<Enemy> CurrentEnemies => _enemiesThisCycle;

    private List<Enemy> _enemiesThisCycle;

    private float _currentSpawnPerSeconds;

    private float _currentSpawnSecs = 0;

    private int _currentNumEnemies = 0;

    void Awake()
    {
        _currentSpawnPerSeconds = _baseSpawnEveryXSeconds;
        _enemiesThisCycle = new List<Enemy>();
    }

    public void BeginAttackCycle()
    {
        // add a few enemies?
    }

    public void TickAttackCycle()
    {
        _currentSpawnSecs += Time.deltaTime;
        if(_currentSpawnSecs >= _currentSpawnPerSeconds)
        {
            _currentSpawnSecs = 0;
            SummonEnemy(_types[Random.Range(0, _types.Length)]);
        }
        for(int i = 0; i < _enemiesThisCycle.Count; i++)
        {
            // put in isdead tag if needed
            _enemiesThisCycle[i].TickAttack();
        }
    }

    public void EndAttackCycle()
    {
        // kill all current enemies
        for (int i = 0; i < _enemiesThisCycle.Count; i++)
        {
            // hopefully performance will be okay
            _enemiesThisCycle[i].Kill();
        }
        _enemiesThisCycle.Clear();
        _currentSpawnPerSeconds -= 1;
        if(_currentSpawnPerSeconds < 1)
        {
            _currentSpawnPerSeconds = 1.0f;
        }
    }

    private void SummonEnemy(EnemyType type)
    {
        Enemy enemy = Instantiate(_protoEnemy);
        enemy.CreateEnemySprite(_bouncePoints, _placeSys, _peopleSys);
        enemy.transform.position = _spawnPosition.position;
        enemy.Type = type; // todo select type
        enemy.PosInEnemyList = _enemiesThisCycle.Count;
        enemy.EnemyKilled += (sender, info) =>
        {
            // set it inactive
            _enemiesThisCycle[info.listPos].gameObject.SetActive(false);
            _currentNumEnemies--;
            if(_currentNumEnemies <= 0)
            {
                AllEnemiesDead();
            }
        };
        _currentNumEnemies++;
        _enemiesThisCycle.Add(enemy);
    }

    private void AllEnemiesDead()
    {
        for (int i = 0; i < _enemiesThisCycle.Count; i++)
        {
            // hopefully performance will be okay
            Destroy(_enemiesThisCycle[i]);
        }
    }
}
