﻿using UnityEngine;
using TMPro;
public class EventPopupSystem : MonoBehaviour
{
    [SerializeField] private RectTransform _eventDisplayCanvas = default;
    [SerializeField] private TextMeshProUGUI _textComponent = default;
    [SerializeField] private EventClosed _closed = default;
    [SerializeField] private RectTransform _defenseRect = default;
    [SerializeField] private RectTransform _moraleRect = default;
    [SerializeField] private RectTransform _popRect = default;
    [SerializeField] private TextMeshProUGUI _defenseMod = default;
    [SerializeField] private TextMeshProUGUI _moraleMod = default;
    [SerializeField] private TextMeshProUGUI _popMod = default;
    [SerializeField] private TextMeshProUGUI _eventAnnounce = default;

    void Awake()
    {
        _eventDisplayCanvas.gameObject.SetActive(false);
        _defenseRect.gameObject.SetActive(false);
        _popRect.gameObject.SetActive(false);
        _moraleRect.gameObject.SetActive(false);
    }

    public void SetEventClosed(EventClosed closed)
    {
        _closed = closed;
    }

    public void EventActive(InGameEvent gameEvent)
    {
        _eventDisplayCanvas.gameObject.SetActive(true);
        _textComponent.text = gameEvent.Description;
        int defenseMod = gameEvent.DefenseModify;
        int moraleMod = gameEvent.MoraleModify;
        int popMod = gameEvent.PeopleNumModify;
        bool goodEvent = gameEvent.IsGoodEvent;

        if(goodEvent)
        {
            _eventAnnounce.text = "Yay!";
        }
        else
        {
            _eventAnnounce.text = "Oh no!";
        }

        if(defenseMod != 0)
        {
            _defenseRect.gameObject.SetActive(true);
            _defenseMod.text = defenseMod.ToString();
        }

        if(moraleMod != 0) 
        {
            _moraleRect.gameObject.SetActive(true);
            _moraleMod.text = moraleMod.ToString();
        }

        if(popMod != 0)
        {
            _popRect.gameObject.SetActive(true);
            _popMod.text = popMod.ToString();
        }
    }

    public void EventClosed()
    {
        _eventDisplayCanvas.gameObject.SetActive(false);
        _defenseRect.gameObject.SetActive(false);
        _popRect.gameObject.SetActive(false);
        _moraleRect.gameObject.SetActive(false);
        _closed();
    }
}

public delegate void EventClosed();
