﻿using TMPro;
using UnityEngine;
using UnityEngine.UI;
public class GameStateDisplay : MonoBehaviour
{
    [SerializeField] private TextMeshProUGUI _idlesPopDisplay = default;
    [SerializeField] private TextMeshProUGUI _builderPopDisplay = default;
    [SerializeField] private TextMeshProUGUI _guardsPopDisplay = default;
    [SerializeField] private TextMeshProUGUI _medicsPopDisplay = default;
    [SerializeField] private TextMeshProUGUI _resourceAmount = default;
    [SerializeField] private TextMeshProUGUI _moraleGain = default;
    [SerializeField] private TextMeshProUGUI _currentDefense = default;
    [SerializeField] private TextMeshProUGUI _currentGuardText = default;
    [SerializeField] private TextMeshProUGUI _currentPopText = default;
    [SerializeField] private Slider _moraleSlider = default;
    [SerializeField] private Slider _defenseSlider = default;
    [SerializeField] private Slider _guardSlider = default;
    [SerializeField] private GameState _gameState = default;
    [SerializeField] private MoraleDefenseSystem _sys = default;
    [SerializeField] private PeopleSystem _peepSys = default;

    void Awake()
    {
        _gameState.SliderValuesChanged += (sender, args) =>
        {
            // ignore args
            UpdateSliders();
        };
        _peepSys.GuardCountChanged += (sender, args) =>
        {
            // ignore args
            UpdateSliders();
        };
    }

    // Late is called once per frame
    void LateUpdate()
    {
        int moraleGain = _sys.MoraleGain;
        if (moraleGain >= 0)
        {
            _moraleGain.text = "+" + moraleGain;
        }
        else
        {
            _moraleGain.text = "-" + moraleGain;
        }
        _idlesPopDisplay.text = _peepSys.PercentIdles + "%";
        _builderPopDisplay.text = _peepSys.PercentBuilders + "%";
        _guardsPopDisplay.text = _peepSys.PercentGuards + "%";
        _medicsPopDisplay.text = _peepSys.PercentMedics + "%";
        _resourceAmount.text = _gameState.ResourceCount.ToString();
        _defenseSlider.value = _sys.Defense;
        _guardSlider.value = _peepSys.CurrentGuardCount;
        _moraleSlider.value = _sys.CurrentMorale;
        _currentDefense.text = _sys.Defense.ToString();
        _currentPopText.text = _sys.NumPeople.ToString();
        _currentGuardText.text = _peepSys.CurrentGuardCount.ToString();
    }

    public void UpdateSliders()
    {
        _defenseSlider.maxValue = _sys.Defense;
        _guardSlider.maxValue = _peepSys.CurrentGuardCount;
        _moraleSlider.maxValue = _sys.MaxMorale;
    }
}
