﻿using System;
using UnityEngine;
[CreateAssetMenu(menuName = "InGameEventSystem")]
public class InGameEventSystem : ScriptableObject
{
    [SerializeField] private InGameEvent[] _neutralEvents = default;
    [SerializeField] private InGameEvent[] _okayEvents = default;
    [SerializeField] private InGameEvent[] _worryingEvents = default;
    [SerializeField] private InGameEvent[] _frighteningEvents = default;
    [SerializeField] private InGameEvent[] _castrophicEvents = default;
    [SerializeField] private PerfWeights _perfWeights = default;

    public InGameEvent GetRandomEvent()
    {
        int bucket = UnityEngine.Random.Range(0, 3);
        switch(bucket)
        {
            case 0:
                {
                    return _neutralEvents[UnityEngine.Random.Range(0, _neutralEvents.Length)];
                }
            case 1:
                {
                    return _okayEvents[UnityEngine.Random.Range(0, _okayEvents.Length)];
                }
            case 2:
                {
                    return _worryingEvents[UnityEngine.Random.Range(0, _worryingEvents.Length)];
                }
            default:
                {
                    throw new Exception("Programmer error, switch does not cover all random cases");
                }
        }
    }

    public Tuple<InGameEvent, float> GetEventBasedOnPerformance(float defenseLeftPercent, 
        float guardsLeftPrecent, float moraleLeftPercent, float buildingsLeftPercent, float gridSpacesLeftPercent)
    {
        float perfMeasure = _perfWeights.GridSpacesLeftWeight * gridSpacesLeftPercent
            + _perfWeights.BuildingsLeftWeight * buildingsLeftPercent
            + _perfWeights.MoraleLeftWeight * moraleLeftPercent
            + _perfWeights.GuardsLeftWeight * guardsLeftPrecent
            + _perfWeights.DefenseLeftWeight * defenseLeftPercent;
        if(perfMeasure > 4.0f)
        {
            return Tuple.Create(_neutralEvents[UnityEngine.Random.Range(0, _neutralEvents.Length)], perfMeasure);
        }
        else if(perfMeasure > 3.0f)
        {
            return Tuple.Create(_okayEvents[UnityEngine.Random.Range(0, _okayEvents.Length)], perfMeasure);
        }
        else if (perfMeasure > 2.0f)
        {
            return Tuple.Create(_worryingEvents[UnityEngine.Random.Range(0, _worryingEvents.Length)], perfMeasure);
        }
        else if (perfMeasure > 1.0f)
        {
            return Tuple.Create(_frighteningEvents[UnityEngine.Random.Range(0, _frighteningEvents.Length)], perfMeasure);
        }
        else
        {
            return Tuple.Create(_castrophicEvents[UnityEngine.Random.Range(0, _castrophicEvents.Length)], perfMeasure);
        }
    }
}

