﻿using System;
using System.Collections.Generic;
using UnityEngine;

public class Guard : MonoBehaviour
{
    [SerializeField] private Sprite _sprite = default;
    [SerializeField] private int _baseHP = default;
    [SerializeField] private SpriteRenderer _render = default;
    [SerializeField] private PlacementSystem _sys = default;
    [SerializeField] private EnemySystem _enemySys = default;
    [SerializeField] private float _minBuildingDistance = default;
    [SerializeField] private float _minEngageDist = default;
    [SerializeField] private float _moveSpeed = default;
    [SerializeField] private float _attackEveryxSeconds = default;
    [SerializeField] private int _attackDamage = default;

    public int PosInGuardsList { get; set; }

    public bool IsAlive => _currentHP > 0;

    public event EventHandler<EntityKilledArgs> GuardKilled;

    private int _currentHP;

    private float _currentSecondTime = 0;

    private float _currentAttackTime = 0;

    private void Start()
    {
        _currentHP = _baseHP;
        if(_sprite !=null)
        {
            _render.sprite = _sprite;
        }
    }

    public void TickAttack()
    {
        Tuple<bool, GridSpace> closestLivingSpace = ClosestLivingSpace();
        if(closestLivingSpace.Item1)
        {
            GridSpace space = closestLivingSpace.Item2;
            if(Vector2.Distance(space.WorldSpace.position, transform.position) 
                > _minBuildingDistance)
            {
                transform.Translate(new Vector2(_moveSpeed, 0) * Time.deltaTime);
            }
            else
            {
                AttackClosetEnemy();
            }
        }
        else
        {
            AttackClosetEnemy();
        }
    }

    public void GetAttacked(int amount)
    {
        _currentHP -= amount;
        if(_currentHP <= 0)
        {
            // todo play death
            GuardKilled?.Invoke(this, new EntityKilledArgs
            {
                listPos = PosInGuardsList
            });
        }
    }

    private void AttackClosetEnemy()
    {
        // go through group of enemies and try and find closet
        List<Enemy> enemyList = new List<Enemy>(_enemySys.CurrentEnemies);
        int closestEnemy = -1;
        for(int i = 0; i < enemyList.Count; i++)
        {
            if(Vector2.Distance(enemyList[i].transform.position, transform.position) < _minEngageDist)
            {
                closestEnemy = i;
            }
        }
        if(closestEnemy > -1)
        {
            _currentAttackTime += Time.deltaTime;
            if(_currentAttackTime >= _attackEveryxSeconds)
            {
                _currentAttackTime = 0;
                enemyList[closestEnemy].TakeDamage(_attackDamage);
            }
        }
        // no enemy to attack;
        else
        {
            _currentAttackTime = 0;
        }
    }

    public void TickPeaceful()
    {
        // unsure
    }

    private Tuple<bool, GridSpace> ClosestLivingSpace()
    {
        Tuple<bool, GridSpace> value = new Tuple<bool, GridSpace>(false, null);
        GridSpace[,] spaces = _sys.BuildingGrid;
        int x = -1;
        int y = -1;
        for(int i = 0; i < _sys.MaxGridX; i++)
        {
            for(int j = 0; j < _sys.MaxGridY; j++)
            {
                if(spaces[i, j].IsAlive && 
                    Vector2.Distance(spaces[i, j].WorldSpace.position
                    , transform.position) < _minBuildingDistance)
                {
                    if(x > -1 && y > -1)
                    {
                        if(Vector2.Distance(spaces[x, y].WorldSpace.position, transform.position)
                            > Vector2.Distance(spaces[i, y].WorldSpace.position, transform.position))
                        {
                            x = i;
                            y = j;
                        }
                    } else
                    {
                        x = i;
                        y = j;
                    }
                }
            }
        }
        if(x > -1 && y > -1)
        {
            value = new Tuple<bool, GridSpace>(true, spaces[x, y]);
        }
        return value;
    }
}
