﻿using System;
using UnityEngine;
public class CycleSystem : MonoBehaviour
{
    [SerializeField] private int _minTimeBetweenCycles = default;

    public bool IsPeaceful { get; private set; } = true;

    public int CurrentTimeInSeconds { get; private set; } = 0;

    public event EventHandler<CycleChangeEventArgs> OnCycleChanged;

    private int _secondTimeBetweenCycles = 0;
    private float _currentSecondTime = 0;

    private bool _cycleRunning = false;

    void Awake()
    {
        _secondTimeBetweenCycles = _minTimeBetweenCycles * 60;
    }

    public void ResetCycle()
    {
        _currentSecondTime = 0;
        CurrentTimeInSeconds = 0;
    }
    
    public void TickCycle()
    {
        _currentSecondTime += Time.deltaTime;
        if (_currentSecondTime >= 1.0f)
        {
            _currentSecondTime = 0;
            CurrentTimeInSeconds += 1;
            if (CurrentTimeInSeconds >= +_secondTimeBetweenCycles)
            {
                ResetCycle();
                IsPeaceful = !IsPeaceful;
                OnCycleChanged?.Invoke(this, new CycleChangeEventArgs
                {
                    isPeaceful = IsPeaceful
                });
            }
        }
        
    }
}
