﻿using System;
using UnityEngine;

public class MoraleDefenseSystem : MonoBehaviour
{
    [SerializeField] private int _originalMorale = default;
    [SerializeField] private int _originalDefense = default;
    [SerializeField] private int _originalNumPeople = default;
    [SerializeField] [Range(10, 20)] private int _baseMoraleGain = 20;

    public int CurrentMorale { get; private set; }

    public int MoraleGain
    {
        get
        {
            return _baseMoraleGain + MedicMoraleGain + BuildingMoraleGain - PopulationMoraleDrain;
        }
    }

    public int MedicMoraleGain { get; set; }

    public int PopulationMoraleDrain { get; set; }

    public int BuildingMoraleGain { get; set; }

    public int MaxMorale { get; private set; }
    
    public int Defense { get; private set; }

    public int NumPeople { get; private set; }

    private float _currentSecondCount = 0;

    private float _currentPeopleSecondCount = 0;

    void Start()
    {
        MaxMorale = _originalMorale;
        CurrentMorale = MaxMorale;
        Defense = _originalDefense;
        NumPeople = _originalNumPeople;
    }

    public void ModifyDefense(int amount)
    {
        Defense += amount;
    }

    public void ModifyPeople(int amount)
    {
        NumPeople += amount;
    }

    public void ModifyMaxMorale(int amount)
    {
        MaxMorale += amount;
        if(CurrentMorale > MaxMorale)
        {
            CurrentMorale = MaxMorale;
        }
    }

    public void ModifyCurrentMorale(int amount)
    {
        CurrentMorale += amount;
        if(CurrentMorale > MaxMorale)
        {
            CurrentMorale = MaxMorale;
        }
    }

    public void TickCycle()
    {
        _currentSecondCount += Time.deltaTime;
        if(_currentSecondCount >= 1.0f)
        {
            _currentSecondCount = 0;
            ModifyCurrentMorale(MoraleGain);
        }
    }

    public void TickPeacefulCycle()
    {
        _currentPeopleSecondCount += Time.deltaTime;
        if(_currentPeopleSecondCount >= 1.0f)
        {
            _currentPeopleSecondCount = 0;
            NumPeople += 3;
        }
    }
}
